#
# spec file for package hddtemp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2002-2012 Manfred Tremmel <Manfred.Tremmel@iiv.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define veronly 0.3
%define state   beta15_e16aed6

Name:           hddtemp
Version:        %{veronly}_%{state}
Release:        bp155.2.12
Summary:        Hard disk temperature tool
License:        GPL-2.0+
Group:          System/Monitoring
Summary(de):    Festplatten Temperatur-Ausleseprogramm
Url:            https://github.com/guzu/hddtemp
Source0:        %{name}-%{veronly}-%{state}.tar.bz2
Source1:        %{name}.db
Source2:        %{name}.init
Source3:        %{name}.sysconfig
Source4:        %{name}.service
Patch0:         hddtemp-db.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  net-tools
BuildRequires:  perl
BuildRequires:  syslogd
%if %suse_version >= 1210
BuildRequires:  systemd
%define has_systemd 1
%else
PreReq:         insserv
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
hddtemp is tool that gives you the temperature of your hard drive by
reading S.M.A.R.T. information.

%description -l de
htddtemp ist ein Tool zum auslesen der Festplattentemperatur aus den
S.M.A.R.T Informationenen.

%prep
%setup -q -n %{name}-%{veronly}-%{state}

cp -p %{SOURCE1} ./hddtemp.db
%patch0

%build
aclocal -I m4
autoconf
automake --add-missing --foreign --copy
CFLAGS="%{optflags} -D_GNU_SOURCE" \
%configure
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}%{_sysconfdir}/default
mkdir -p %{buildroot}%{_datadir}/misc/
mkdir -p %{buildroot}%{_fillupdir}
install -m 0644 hddtemp.db %{buildroot}%{_datadir}/misc/
pushd %{buildroot}%{_sysconfdir}
ln -s ..%{_datadir}/misc/hddtemp.db ./hddtemp.db
popd
install -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.%{name}

%if 0%{?has_systemd}
install -D -m0644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
%else
mkdir -p %{buildroot}%{_initddir}
install -m 0755 %{SOURCE2} %{buildroot}%{_initddir}/%{name}
pushd %{buildroot}%{_sbindir}
ln -s ../..%{_initddir}/%{name} rc%{name}
popd
%endif

%find_lang %{name}

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%post
%{fillup_only %{name}}
%if 0%{?has_systemd}
%service_add_post %{name}.service
%endif

%files -f %{name}.lang
%defattr(-,root,root)
%doc COPYING README TODO contribs
%{_datadir}/misc/hddtemp.db
%{_fillupdir}/sysconfig.%{name}
%config(noreplace) %{_sysconfdir}/hddtemp.db
%doc %{_mandir}/man8/hddtemp.8*
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/%{name}
%endif

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Apr 27 2017 dimstar@opensuse.org
- Unconditionally call fillup_only also on systemd setups: the
  sysconfig file is also valid for the systemd service
  (boo#1034379).
* Wed Mar 15 2017 dimstar@opensuse.org
- Only install the init.d service when there is no systemd present:
  the systemd service would mask it and only confuses users that
  try to debug things.
- Link rc%%{name} to /usr/sbin/service when using systemd.
- Move the insserv BuildRequires to be a PreReq (it's not used for
  the build system, but actually for the installation on a machine)
  and guard it to be validonly for non-systemd systems.
* Sun Mar 12 2017 plinnell@opensuse.org
- Add insserv as build requirement to fix Factory build
* Sun Feb  9 2014 xrigou@otenet.gr
- Apply spec-cleaner 0.5.4
- Fix fillup bug
- Fix some rpmlint warnings
- Eliminate double configure
* Tue Nov  5 2013 mopp@gmx.net
- Latest version from GitHub e16aed6
- systemd service support
* Thu May 24 2012 pascal.bleser@opensuse.org
- moved to build.opensuse.org upon request:
  https://bugs.links2linux.org/browse/PM-25
* Mon Apr 23 2012 pascal.bleser@opensuse.org
- fixes to build on openSUSE >= 12.1 on 32bit, needs passing -D_GNU_SOURCE to
  compiler
- modernize spec file a little towards nowadays factory compliance
* Wed Sep 16 2009 Manfred.Tremmel@iiv.de
- fixes in post/pre scripts
* Tue Sep  8 2009 Manfred.Tremmel@iiv.de
- cleanups where rpmlint wasn't so happy
* Thu Mar 29 2007 Manfred.Tremmel@iiv.de
- added patches from devil_at_decagon.de and debian
* Wed May  3 2006 Manfred.Tremmel@iiv.de
- Update to 0.3beta15
* Wed Sep 21 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta14
* Sat Apr  2 2005 Manfred.Tremmel@iiv.de
- readded a script from Mr.Bool in post section
* Wed Mar 23 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta13
* Thu Mar 17 2005 Manfred.Tremmel@iiv.de
- readded chmod +s, sorry was missing
* Wed Mar 16 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta12
* Sun Dec  7 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta9
* Sat Aug 16 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta8
* Sat Jun 21 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta7
* Sat Apr 19 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta6
* Mon Mar 24 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta5
  Thu Mar 13 00:00:00 UTC 2003 - Mr.Bool <mr.bool at rambler.ru>
- Update to 0.3beta4
* Sat Jan 25 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta3
* Sat Jan  4 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta2
  Wed Dec  4 00:00:00 UTC 2002 - Mr.Bool <mr.bool at rambler.ru>
- some cleanups : hddtemp.sysconfig , hddtemp.spec
* Sun Dec  1 2002 Manfred.Tremmel@iiv.de
- Update to 0.3beta1
  Sat Oct 12 00:00:00 UTC 2002 - Mr.Bool <mr.bool at rambler.ru> 0.3-0.alpha.3cr_SuSE8.x
- Rebuild for SuSE 8.0.
- Added /etc/bash.bashrc.local creation
- New init script (LSB compatible?)
- Configuration has more parameters
- Suid root again
- Spec file changed
- Default drive is /dev/hda
  Sun Oct  6 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.3cr
- Rebuild for Red Hat 8.0.
  Tue Aug 13 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.2cr
- Patched db.
  Sat Aug  3 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.1cr
- Update to 0.3 alpha.
- No more suid root.
  Tue Jul 30 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-4cr
- hddtemp.db version 19.
  Tue Jul 23 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-3cr
- hddtemp.db version 18.
  Wed Jul 10 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-2cr
- hddtemp.db version 17.
  Tue Jul  2 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-1cr
- Updated hddtemp.db.
  Thu Jun  6 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-0.1
- Initial build.
